@@ -4,6 +4,7 @@ from .gaussian_random_walks import GaussianRandomWalks
 from .linear_redundant import LinearRedundant
 from .nonlinear_redundant import NonlinearRedundant
 from .random_irrelevant import RandomIrrelevant
+from .single_precision import SinglePrecision
 from .time_aware_env import AddRelativeTimestep
 
 
@@ -14,4 +15,5 @@ __all__ = [
     "LinearRedundant",
     "NonlinearRedundant",
     "RandomIrrelevant",
+    "SinglePrecision",
 ]
